@@ -10,10 +10,10 @@ function field_list = gd_mvector_list(D, parent)
 %   See also GD_ENTRY_LIST, GETDATA_CONSTANTS
 
   GD = getdata_constants();
-  field_list = gd_entry_list(D, parent, GD.VECTOR_ENTRIES, 0);
+  field_list = gd_entry_list(D, parent, GD.VECTOR_ENTRIES);
 end
 
-% Copyright (C) 2013 D. V. Wiebe
+% Copyright (C) 2013, 2016 D. V. Wiebe
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
