@@ -28,17 +28,14 @@ static struct {
   char *doc;
 } gdpy_exception_list[GD_N_ERROR_CODES] = {
   { NULL, NULL },
-  { NULL, NULL }, /* 1 */
   { "Format", "Syntax error in Dirfile metadata (GD_E_FORMAT)." },
-  { NULL, NULL }, /* 3 */
   { "Creation", "Unable to create a Dirfile. (GD_E_CREAT)." },
   { "BadCode", "Bad field code. (GD_E_BAD_CODE)." },
   { "BadType", "Bad data type. (GD_E_BAD_TYPE)." },
   { "IO", "I/O error encountered. (GD_E_IO)." },
-  { NULL, NULL }, /* 8 */
-  { "Internal", "Internal library error (GD_E_INTERNAL_ERROR).\nPlease report "
-    "to <" PACKAGE_BUGREPORT ">" },
-  { NULL, NULL }, /* 10 -- GD_E_ALLOC.  Reported via PyErr_NoMemory() */
+  { "Internal", "Internal library error (GD_E_INTERNAL_ERROR).\n"
+    "Please report to <" PACKAGE_BUGREPORT ">" },
+  { NULL, NULL }, /* GD_E_ALLOC.  Reported via PyErr_NoMemory() */
   { "Range", "Invalid frame or sample number (GD_E_RANGE)." },
   { "LUT", "Malformed LINTERP table file (GD_E_LUT)." },
   { "RecurseLevel", "Recursion too deep (GD_E_RECURSE_LEVEL)." },
@@ -63,13 +60,10 @@ static struct {
   { "UncleanDatabase",
     "Error updating Dirfile: database is unclean (GD_E_UNCLEAN_DB)." },
   { "Domain", "Improper domain (GD_E_DOMAIN)." },
-  { NULL, NULL }, /* 32 */
-  { NULL, NULL }, /* 33 */
-  { NULL, NULL }, /* 34 */
   { "Bounds", "CARRAY access out-of-bounds (GD_E_BOUNDS)." },
   { "LineTooLong", "Metadata line is too long (GD_E_LINE_TOO_LONG)." }
 };
-PyObject *gdpy_exceptions[GD_N_ERROR_CODES];
+static PyObject *gdpy_exceptions[GD_N_ERROR_CODES];
 
 /* These are unused but for backwards compatibility are defined as aliases of
  * current exceptions */
@@ -77,21 +71,39 @@ static struct {
   const char *name;
   int e;
 } gdpy_dead_exceptions[] = {
-  { "BadEndianness", GD_E_ARGUMENT },
-  { "BadProtection", GD_E_ARGUMENT },
-  { "BadRepr", GD_E_BAD_CODE },
-  { "BadVersion", GD_E_ARGUMENT },
-  { "OpenLinfile", GD_E_LUT },
-  { "Flush", GD_E_IO },
-  { "Open", GD_E_IO },
-  { "OpenFragment", GD_E_IO },
-  { "OpenFragment", GD_E_IO },
-  { "OpenInclude", GD_E_IO },
-  { "RawIO", GD_E_IO },
-  { "Trunc", GD_E_IO },
+  { "BadEndianness", -GD_E_ARGUMENT },
+  { "BadProtection", -GD_E_ARGUMENT },
+  { "BadRepr", -GD_E_BAD_CODE },
+  { "BadVersion", -GD_E_ARGUMENT },
+  { "OpenLinfile", -GD_E_LUT },
+  { "Flush", -GD_E_IO },
+  { "Open", -GD_E_IO },
+  { "OpenFragment", -GD_E_IO },
+  { "OpenFragment", -GD_E_IO },
+  { "OpenInclude", -GD_E_IO },
+  { "RawIO", -GD_E_IO },
+  { "Trunc", -GD_E_IO },
   { NULL, 0}
 };
 
+char *gdpy_strdup(const char *str)
+{
+  char *ptr = NULL;
+
+  dtrace("\"%s\"", str);
+
+  if (str) {
+    size_t len = strlen(str) + 1;
+    ptr = PyMem_Malloc(len);
+
+    if (ptr)
+      memcpy(ptr, str, len);
+  }
+
+  dreturn("%p", ptr);
+  return ptr;
+}
+
 int gdpylist_append(PyObject *list, PyObject *item)
 {
   int ret;
@@ -258,23 +270,27 @@ long gdpy_long_from_pyobj(PyObject *pyobj)
   return v;
 }
 
-/* Convert a Python string-like object to a C string, returns a malloc'd
- * string in all cases */
+/* Convert a Python string-like object to a C string, returns a PyMem_Malloc'd
+ * string except on error */
 char *gdpy_string_from_pyobj(PyObject *pyobj, const char *char_enc,
     const char *err_string)
 {
+  PyObject *encobj = NULL;
   char *s = NULL;
-  int del_pyobj = 0;
 
   dtrace("%p, \"%s\"", pyobj, char_enc);
 
   if (PyUnicode_Check(pyobj)) {
-    del_pyobj = 1;
     /* Encode string */
     if (char_enc == NULL)
-      pyobj = PyUnicode_AsUTF8String(pyobj);
+      encobj = PyUnicode_AsUTF8String(pyobj);
     else
-      pyobj = PyUnicode_AsEncodedString(pyobj, char_enc, "strict");
+      encobj = PyUnicode_AsEncodedString(pyobj, char_enc, "strict");
+
+    if (encobj == NULL) {
+      dreturn("%p", NULL);
+      return NULL;
+    }
   } else if (!gdpy_encobj_check(pyobj)) {
     if (err_string)
       PyErr_SetString(PyExc_TypeError, err_string);
@@ -283,19 +299,20 @@ char *gdpy_string_from_pyobj(PyObject *pyobj, const char *char_enc,
   }
 
   /* now convert to python object */
-  s = gdpy_string_from_encobj(pyobj);
+  if (encobj) {
+    s = gdpy_string_from_encobj(encobj);
+    Py_DECREF(encobj);
+  } else
+    s = gdpy_string_from_encobj(pyobj);
 
   /* strdup */
   if (s) {
-    s = strdup(s);
+    s = gdpy_strdup(s);
 
     if (s == NULL)
       PyErr_NoMemory();
   }
 
-  if (del_pyobj)
-    Py_DECREF(pyobj);
-
   dreturn("\"%s\"", s);
   return s;
 }
@@ -361,7 +378,7 @@ char *gdpy_path_from_pyobj_(PyObject *pyobj, int dup)
 
   /* strdup, if requested */
   if (s && dup) {
-    s = strdup(s);
+    s = gdpy_strdup(s);
 
     if (s == NULL)
       PyErr_NoMemory();
@@ -570,7 +587,7 @@ gd_type_t gdpy_type_from_npytype(int npytype)
       break;
   }
 
-  dreturn("0x%03x\n", type);
+  dreturn("0x%03x", type);
   return type;
 }
 
@@ -650,14 +667,14 @@ int gdpy_report_error(DIRFILE *D, char *char_enc)
 
   e = gd_error(D);
 
-  if (e == GD_E_ALLOC) {
+  if (e == GD_E_ALLOC)
     PyErr_NoMemory();
-  } else if (e) {
+  else if (e) {
     char *buffer = gd_error_string(D, NULL, 0);
     if (buffer) {
-      PyErr_SetObject(gdpy_exceptions[e], gdpyobj_from_estring(buffer,
+      PyErr_SetObject(gdpy_exceptions[-e], gdpyobj_from_estring(buffer,
             char_enc));
-      free(buffer); 
+      PyMem_Free(buffer); 
     } else
       PyErr_NoMemory(); /* Errors with errors */
   }
@@ -748,6 +765,7 @@ PyObject *gdpy_convert_to_pylist(const void *data, gd_type_t type, size_t ns)
         if (gdpylist_append(pyobj, gdpy_from_complexp(((double*)data) + 2 * i)))
           return NULL;
       break;
+    case GD_STRING:
     case GD_NULL:
     case GD_UNKNOWN: /* prevent compiler warning */
       break;
@@ -808,6 +826,7 @@ PyObject *gdpy_convert_to_pyobj(const void *data, gd_type_t type,
       pyobj = gdpy_maybe_complex(((double*)data)[0], ((double*)data)[1],
           force_complex);
       break;
+    case GD_STRING:
     case GD_UNKNOWN: /* prevent compiler warning */
       break;
   }
@@ -816,24 +835,25 @@ PyObject *gdpy_convert_to_pyobj(const void *data, gd_type_t type,
   return pyobj;
 }
 
-/* If value is a valid encoding (or None), free the old *char_enc and update */
+/* If value is a valid encoding (or None), PyMem_Free the old *char_enc and
+ * update */
 int gdpy_parse_charenc(char** char_enc, PyObject *value)
 {
   dtrace("%p, %p", char_enc, value);
 
   if (value == NULL || value == Py_None) {
-    free(*char_enc);
+    PyMem_Free(*char_enc);
     *char_enc = NULL;
   } else {
     char *new_enc = gdpy_string_from_pyobj(value, NULL,
         "character_encoding must be string or None");
   
-    if (PyErr_Occurred()) {
+    if (new_enc == NULL) {
       dreturn("%i", -1);
       return -1;
     }
 
-    free(*char_enc);
+    PyMem_Free(*char_enc);
     *char_enc = new_enc;
   }
 
@@ -1145,5 +1165,8 @@ GDPY_MODINITFUNC
     PyModule_AddObject(gdpy_mod, "__CAPI", capi);
 #endif
 
+  /* Tell GetData to use Python's heap (in places) */
+  gd_alloc_funcs(PyMem_Malloc, PyMem_Free);
+
   GDPY_MODINITSUCCESS;
 }
