@@ -528,7 +528,7 @@ static size_t _GD_GetIndex(double x, const struct gd_lut_ *lut, size_t idx,
     } \
   } while (0)
 
-#define LINTERPC(t) LINTERP(complex t)
+#define LINTERPC(t) LINTERP(_Complex t)
 #endif
 
 #define RLINTERP(t) \
@@ -573,8 +573,8 @@ static size_t _GD_GetIndex(double x, const struct gd_lut_ *lut, size_t idx,
 
 /* _GD_LinterpData: calibrate data using lookup table lut
 */
-void _GD_LinterpData(DIRFILE *restrict D, void *restrict data, gd_type_t type,
-    int complex_table, const double *restrict data_in, size_t npts,
+void _GD_LinterpData(DIRFILE *restrict D, void *data, gd_type_t type,
+    int complex_table, const double *data_in, size_t npts,
     const struct gd_lut_ *restrict lut, size_t n_ln)
 {
   int idx = 0;
@@ -656,7 +656,7 @@ void _GD_LinterpData(DIRFILE *restrict D, void *restrict data, gd_type_t type,
     default: _GD_InternalError(D); \
   }
 #else
-#define LINCOMC(t) LINCOM(complex t)
+#define LINCOMC(t) LINCOM(_Complex t)
 #endif
 
 #define LINCOM(t) \
@@ -818,7 +818,7 @@ void _GD_CLincomData(DIRFILE *restrict D, int n, void *restrict data1,
     } \
   } while (0)
 #else
-#define INVERTC(t) INVERT(complex t)
+#define INVERTC(t) INVERT(_Complex t)
 #endif
 
 #define INVERT(t) for (i = 0; i < n_read; i++) \
