@@ -1265,7 +1265,7 @@ static size_t _GD_DoBit(DIRFILE *restrict D, gd_entry_t *restrict E,
 
   /* extract bits */
   if (is_signed) {
-    uint64_t sign = -1LL << (E->EN(bit,numbits) - 1);
+    uint64_t sign = 0xFFFFFFFFFFFFFFFFLLU << (E->EN(bit,numbits) - 1);
     for (i = 0; i < n_read; i++)
       ((int64_t *)tmpbuf)[i] =
         (((((uint64_t *)tmpbuf)[i] >> E->EN(bit,bitnum)) & mask) + sign) ^ sign;
