@@ -173,6 +173,21 @@ typedef gd_off64_t off64_t;
 #define O_TRUNC _O_TRUNC
 #endif
 
+#ifdef HAVE_COMPLEX_H
+#include <complex.h>
+#elif defined HAVE_CABS && defined __GNUC__ && (__GNUC__ > 3)
+/* This is a cygwin hack: the Cygwin C library isn't C99 compliant, but gcc 3+
+ * contains built-in versions of these functions */
+#define complex _Complex
+#define _Complex_I (__extension__ 1.0iF)
+double cabs(double _Complex z);
+double carg(double _Complex z);
+#define cexp(z) (exp(__real__ (z)) * (cos(__imag__ (z)) + _Complex_I \
+      * sin(__imag__ (z))))
+double creal(double _Complex z);
+double cimag(double _Complex z);
+#endif
+
 #ifdef GD_NO_C99_API
 /* generic dcomplex pointer for passing around malloc'd vectors */
 #  define GD_DCOMPLEXP_t double *
@@ -237,6 +252,16 @@ typedef gd_off64_t off64_t;
 /* compare a to b */
 #  define gd_ccmpc_(a,b) ((a)[0] == (b)[0] && (a)[1] == (b)[1])
 #else
+#  ifndef CMPLX
+#    ifdef _Imaginary_I
+#      define GD_IMAGINARY_I _Imaginary_I
+#    else
+#      define GD_IMAGINARY_I _Complex_I
+#    endif
+#    define CMPLX(x, y) \
+  ((double _Complex)((double)(x) + GD_IMAGINARY_I * (double)(y)))
+#  endif
+
 #  define GD_DCOMPLEXP_t double _Complex *
 #  define GD_DCOMPLEXA(v) double _Complex v
 #  define GD_DCOMPLEXV(v) double _Complex *restrict v
@@ -244,37 +269,22 @@ typedef gd_off64_t off64_t;
 #  define cimagp(z) cimag(*(z))
 #  define gd_cap_(a,i) (a + i)
 #  define gd_csp_(a) (&(a))
-#  define gd_ra2cs_(a,b) a = *((double complex*)(b))
+#  define gd_ra2cs_(a,b) a = *((double _Complex*)(b))
 #  define gd_cs2cs_(a,b) a = b
 #  define gd_cp2cs_(a,b) a = *(b)
 #  define gd_cs2cp_(a,b) *(a) = b
 #  define gd_ca2cs_(a,b,i) a = b[i]
 #  define gd_cp2ca_(a,i,b) (a)[i] = *(b)
-#  define gd_li2cs_(a,x,y) a = (x + _Complex_I * y)
-#  define gd_li2cp_(a,x,y) *(a) = (x + _Complex_I * y)
+#  define gd_li2cs_(a,x,y) a = CMPLX(x, y)
+#  define gd_li2cp_(a,x,y) *(a) = CMPLX(x, y)
 #  define gd_po2cs_(a,r,p) a = (r) * cexp(p)
 #  define gd_po2cp_(a,r,p) *(a) = (r) * cexp(p)
 #  define gd_rs2cs_(a,b) a = b
 #  define gd_rs2cp_(a,b) *(a) = b
-#  define gd_cs2ca_(a,i,b,t) ((complex t*)a)[i] = (complex t)(b)
+#  define gd_cs2ca_(a,i,b,t) ((_Complex t*)a)[i] = (_Complex t)(b)
 #  define gd_rs2ca_(a,i,b,t) gd_cs2ca_(a,i,b,t)
-#  define gd_ccmpl_(a,x,y) (a == (x + _Complex_I * y))
+#  define gd_ccmpl_(a,x,y) (a == CMPLX(x, y))
 #  define gd_ccmpc_(a,b) (a == b)
-
-#ifdef HAVE_COMPLEX_H
-#include <complex.h>
-#elif defined HAVE_CABS && defined __GNUC__ && (__GNUC__ > 3)
-/* This is a cygwin hack: the Cygwin C library isn't C99 compliant, but gcc 3+
- * contains built-in versions of these functions */
-#define complex _Complex
-#define _Complex_I (__extension__ 1.0iF)
-double cabs(double complex z);
-double carg(double complex z);
-#define cexp(z) (exp(__real__ (z)) * (cos(__imag__ (z)) + _Complex_I \
-      * sin(__imag__ (z))))
-double creal(double complex z);
-double cimag(double complex z);
-#endif
 #endif
 
 #ifndef NAN
@@ -1029,7 +1039,9 @@ struct gd_private_entry_ {
   union {
     struct { /* RAW */
       char* filebase;
-      size_t size;
+      size_t size; /* Data type size */
+      time_t atime; /* Access time, with second resolution */
+      int fd_count; /* Number of open files */
       struct gd_raw_file_ file[2]; /* encoding framework data */
     } raw;
     struct { /* LINTERP */
@@ -1232,6 +1244,11 @@ struct gd_dirfile_ {
   int n_error;
   int lookback;
 
+  /* for TMOF avoidance */
+  long open_limit, open_fds, open_raws;
+  int opened_sorted;
+  gd_entry_t **opened;
+
   /* for the public tokeniser */
   char *tok_base;
   const char *tok_pos;
@@ -1245,7 +1262,7 @@ struct gd_dirfile_ {
   /* the reference field */
   gd_entry_t* reference_field;
 
-  /* directory name (this is just whatever was passed to gd_open() */
+  /* directory name (this is just whatever was passed to gd_open()) */
   char* name;
 
   /* directory list */
@@ -1314,6 +1331,7 @@ int _GD_MakeTempFile(const DIRFILE*, int, char*);
 
 /* forward declarations */
 void *_GD_Alloc(DIRFILE*, gd_type_t, size_t) __attribute_malloc__;
+int _GD_AutoClose(DIRFILE*, int);
 
 #define _GD_BadWindop(op) \
   ( \
@@ -1384,7 +1402,7 @@ int _GD_GrabDir(DIRFILE*, int, const char *restrict, int);
 int _GD_Include(DIRFILE*, struct parser_state *restrict, const char *restrict,
     char **restrict, int, const char *restrict, const char *restrict, int);
 void _GD_InitialiseFramework(void);
-int _GD_InitRawIO(DIRFILE*, const gd_entry_t*, const char*, int,
+int _GD_InitRawIO(DIRFILE*, gd_entry_t*, const char*, int,
     const struct encoding_t*, unsigned int, unsigned int, int);
 void _GD_InvertData(DIRFILE *restrict, void *restrict, gd_type_t return_type,
     double dividend, size_t n_read);
@@ -1399,8 +1417,8 @@ void _GD_LincomData(DIRFILE *restrict, int n, void *restrict,
     gd_type_t return_type, const double *restrict, const double *restrict,
     const double *restrict, const double *restrict,
     const unsigned int *restrict, size_t);
-void _GD_LinterpData(DIRFILE *restrict, void *restrict, gd_type_t, int,
-    const double *restrict, size_t, const struct gd_lut_ *restrict, size_t);
+void _GD_LinterpData(DIRFILE *restrict, void*, gd_type_t, int,
+    const double*, size_t, const struct gd_lut_ *restrict, size_t);
 int _GD_ListEntry(const gd_entry_t*, int, int, int, int, int, gd_entype_t);
 char *_GD_MakeFullPath(DIRFILE *restrict, int, const char *restrict, int);
 void *_GD_Malloc(DIRFILE *D, size_t size) __attribute_malloc__;
