@@ -1,4 +1,4 @@
-/* Copyright (C) 2008-2011 D. V. Wiebe
+/* Copyright (C) 2008-2011, 2017 D.V. Wiebe
  *
  ***************************************************************************
  *
@@ -21,12 +21,6 @@
 /* Closing a dirfile should succeed cleanly */
 #include "test.h"
 
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <string.h>
-
 int main(void)
 {
   const char *filedir = "dirfile";
@@ -35,8 +29,8 @@ int main(void)
   DIRFILE *D;
 
   rmdirfile();
-  mkdir(filedir, 0777);
-  close(open(format, O_CREAT | O_EXCL | O_WRONLY, 0666));
+  mkdir(filedir, 0700);
+  MAKEEMPTYFILE(format, 0600);
 
   D = gd_open(filedir, GD_RDONLY | GD_VERBOSE);
   error = gd_close(D);
