@@ -28,12 +28,12 @@ int main(void)
 #ifdef GD_NO_C99_API
   float c[16];
 #else
-  float complex c[8];
+  float _Complex c[8];
 #endif
   int i, n, error, r = 0;
   DIRFILE *D;
 
-  memset(c, 0, 8);
+  memset(c, 0, 16 * sizeof(float));
   rmdirfile();
   mkdir(filedir, 0700);
 
@@ -57,7 +57,7 @@ int main(void)
     double v[] = {40 + i, 40 + i};
     CHECKCi(i,c + 2 * i, v);
 #else
-    CHECKCi(i,c[i], (40 + i) * (1 + _Complex_I));
+    CHECKCi(i,c[i], CMPLX(40 + i, 40 + i));
 #endif
   }
 
