@@ -18,7 +18,6 @@
  * along with GetData; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* Attempt to read UINT16 as COMPLEX64 */
 #include "test.h"
 
 int main(void)
@@ -29,12 +28,12 @@ int main(void)
 #ifdef GD_NO_C99_API
   float c[16];
 #else
-  float complex c[8];
+  float _Complex c[8];
 #endif
   int i, n, error, r = 0;
   DIRFILE *D;
 
-  memset(c, 0, 8);
+  memset(c, 0, 16 * sizeof(float));
   rmdirfile();
   mkdir(filedir, 0700);
 
