@@ -1,4 +1,4 @@
-/* Copyright (C) 2014, 2016 D. V. Wiebe
+/* Copyright (C) 2014, 2016, 2017 D.V. Wiebe
  *
  ***************************************************************************
  *
@@ -20,28 +20,18 @@
  */
 #include "test.h"
 
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <string.h>
-#include <errno.h>
-
 int main(void)
 {
   const char *filedir = "dirfile";
   const char *format = "dirfile/format";
-  const char *format_data = "/VERSION 9\ndata RAW UINT8 scalar<3\n";
-  int fd, error, r = 0;
+  int error, r = 0;
   DIRFILE *D;
   gd_entry_t E;
 
   rmdirfile();
-  mkdir(filedir, 0777);
+  mkdir(filedir, 0700);
 
-  fd = open(format, O_CREAT | O_EXCL | O_WRONLY, 0666);
-  write(fd, format_data, strlen(format_data));
-  close(fd);
+  MAKEFORMATFILE(format, "/VERSION 9\ndata RAW UINT8 scalar<3\n");
 
   D = gd_open(filedir, GD_RDONLY);
   error = gd_error(D);
