@@ -1,4 +1,4 @@
-/* Copyright (C) 2008-2011, 2013 D. V. Wiebe
+/* Copyright (C) 2008-2011, 2013, 2016 D. V. Wiebe
  *
  ***************************************************************************
  *
@@ -18,43 +18,30 @@
  * along with GetData; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* Attempt to write UINT8 */
 #include "test.h"
 
-#include <inttypes.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <string.h>
-#include <errno.h>
-
 int main(void)
 {
   const char *filedir = "dirfile";
   const char *format = "dirfile/format";
-  const char *format_data = "data STRING UINT8\nPROTECT all\n";
-  int fd, n, error, r = 0;
+  int n, error, r = 0;
   DIRFILE *D;
 
   rmdirfile();
-  mkdir(filedir, 0777);
+  mkdir(filedir, 0700);
 
-  fd = open(format, O_CREAT | O_EXCL | O_WRONLY, 0666);
-  write(fd, format_data, strlen(format_data));
-  close(fd);
+  MAKEFORMATFILE(format, "data STRING UINT8\nPROTECT all\n");
 
   D = gd_open(filedir, GD_RDWR | GD_UNENCODED);
   n = gd_put_string(D, "data", "some string");
+  CHECKI(n,GD_E_PROTECTED);
   error = gd_error(D);
+  CHECKI(error, GD_E_PROTECTED);
 
   gd_discard(D);
 
   unlink(format);
   rmdir(filedir);
 
-  CHECKI(n,0);
-  CHECKI(error, GD_E_PROTECTED);
-
   return r;
 }
