@@ -18,7 +18,6 @@
  * along with GetData; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* Open a Standards Version 2 conformant dirfile */
 #include "test.h"
 
 int main(void)
@@ -30,7 +29,7 @@ int main(void)
   int i, n, error, v, l, e, r = 0;
   DIRFILE *D;
 
-  memset(c, 0, 8);
+  memset(c, 0, 8 * sizeof(*c));
   rmdirfile();
   mkdir(filedir, 0700);
 
